%PURPOSE: compute the unconstraint Beta weights function
  
%USAGE:
%       [return_Mk,returnsT, date_T]k=returnMk(returns, weights,date)
%where: 
%INPUTS:
%       returns= the matrix of firms returns
%       weights= the matrix of weights
%       date= a specific date T
% -----------------------------------------------------
%OUTPUTS:
%       return_Mk= the vector market returns
%       returnsT= the matrix of firm returns up to date T
%       date_T= the vector of time period up to date T
%------------------------------------------------------
%Written by:  Denisa BANULESCU, Elena DUMITRESCU, march 2012



function [return_Mk,returnsT,date_T]=returnMk(returns, weights,date)
T=find(weights(:,1)==date);             % find the row corresponding to the specific date
TT=find(returns(:,1)==date);            % find the row corresponding to the specific date
wi_T=weights(T,2:end);                  % keep the weights for that date
returnsT=returns(1:TT,2:end);           % returns for assets for the period 1:date
return_Mk=returnsT*wi_T';               % market returns for the same period

date_T=returns(1:TT,1);                 % time-periods 1:date
